==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/BaYhzkLs.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 用海状况
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(name = "ba_yhzk_ls")
public class BaYhzkLs implements Serializable {

    @XmlAttribute
    private String zhdm;

    @XmlAttribute
    private String yhfs;

    @XmlAttribute
    private String yhmj;

    @XmlAttribute
    private String jtyt;

    @XmlAttribute
    private String syjes;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    @id
    @Id
    private String id;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String bsm;

    @XmlAttribute
    private String mbs;

    @XmlAttribute
    private String jedw;

    public String getBsm() {
        return bsm;
    }

    public void setBsm(String bsm) {
        this.bsm = bsm;
    }

    public String getMbs() {
        return mbs;
    }

    public void setMbs(String mbs) {
        this.mbs = mbs;
    }

    public String getJedw() {
        return jedw;
    }

    public void setJedw(String jedw) {
        this.jedw = jedw;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }


    public String getZhdm() {
        return zhdm;
    }

    public void setZhdm(String zhdm) {
        this.zhdm = zhdm;
    }

    public String getYhfs() {
        return yhfs;
    }

    public void setYhfs(String yhfs) {
        this.yhfs = yhfs;
    }

    public String getYhmj() {
        return yhmj;
    }

    public void setYhmj(String yhmj) {
        this.yhmj = yhmj;
    }

    public String getJtyt() {
        return jtyt;
    }

    public void setJtyt(String jtyt) {
        this.jtyt = jtyt;
    }

    public String getSyjes() {
        return syjes;
    }

    public void setSyjes(String syjes) {
        this.syjes = syjes;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }
}

==> realestate-supervise-common-1.1.0-20251204.031512-72-sources.jar: cn/gtmap/realestate/supervise/entity/BaYhzkLs.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 用海状况
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(name = "ba_yhzk_ls")
public class BaYhzkLs implements Serializable {

    @XmlAttribute
    private String zhdm;

    @XmlAttribute
    private String yhfs;

    @XmlAttribute
    private String yhmj;

    @XmlAttribute
    private String jtyt;

    @XmlAttribute
    private String syjes;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    @id
    @Id
    private String id;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String bsm;

    @XmlAttribute
    private String mbs;

    @XmlAttribute
    private String jedw;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段开始===============

    // 不动产单元号
    @XmlAttribute
    private String bdcdyh;

    // 使用空间
    @XmlAttribute
    private String sykj;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段结束===============

    public String getBsm() {
        return bsm;
    }

    public void setBsm(String bsm) {
        this.bsm = bsm;
    }

    public String getMbs() {
        return mbs;
    }

    public void setMbs(String mbs) {
        this.mbs = mbs;
    }

    public String getJedw() {
        return jedw;
    }

    public void setJedw(String jedw) {
        this.jedw = jedw;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }


    public String getZhdm() {
        return zhdm;
    }

    public void setZhdm(String zhdm) {
        this.zhdm = zhdm;
    }

    public String getYhfs() {
        return yhfs;
    }

    public void setYhfs(String yhfs) {
        this.yhfs = yhfs;
    }

    public String getYhmj() {
        return yhmj;
    }

    public void setYhmj(String yhmj) {
        this.yhmj = yhmj;
    }

    public String getJtyt() {
        return jtyt;
    }

    public void setJtyt(String jtyt) {
        this.jtyt = jtyt;
    }

    public String getSyjes() {
        return syjes;
    }

    public void setSyjes(String syjes) {
        this.syjes = syjes;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getSykj() {
        return sykj;
    }

    public void setSykj(String sykj) {
        this.sykj = sykj;
    }
}
